import _objectSpread from "@babel/runtime/helpers/esm/objectSpread";
import { whitespaceCharactersToHTML } from '../Editor/annotation-plugin/annotation';

function sanitizedText(text) {
  var escapedWhitespaces = whitespaceCharactersToHTML(text); // remove whitespaces

  var trimmed = escapedWhitespaces.trim(); // replace dashes at the end of sentence

  var noTrailingDash = trimmed.replace(/-$/, "");
  return noTrailingDash;
}

function getConnectingSymbol(labelName) {
  switch (labelName) {
    case 'text':
      return "";

    case 'appendix':
      return "<br><br>";

    default:
      return "<br>";
  }
}

function blocksToArticle(blocks) {
  var renamedBlocks = blocks.map(function (b) {
    var newBlock = _objectSpread({}, b, {
      data: _objectSpread({}, b.data, {
        labelName: b.data.labelName === 'interview' ? 'text' : b.data.labelName
      })
    });

    return newBlock;
  });
  var article = renamedBlocks.reduce(function (acc, curr) {
    var _ref = curr === null || curr === void 0 ? void 0 : curr.data,
        labelName = _ref.labelName,
        text = _ref.text;

    if (acc[labelName] === undefined) {
      acc[labelName] = "";
    }

    var connectingSymbol = getConnectingSymbol(labelName); // if last symbol is dot, next sentence should start with space

    if (acc[labelName].charAt(acc[labelName].length - 1) === "." && connectingSymbol === "") {
      connectingSymbol = " ";
    }

    acc[labelName] = acc[labelName] + connectingSymbol + sanitizedText(text);
    return acc;
  }, {
    title: "",
    text: ""
  });
  return article;
}

export default blocksToArticle;