import _toConsumableArray from "@babel/runtime/helpers/esm/toConsumableArray";

function labelAndTextFromResultText(resultText) {
  if (!resultText) {
    return {};
  }

  var parsedResultText = JSON.parse(resultText);
  var label = parsedResultText[0].label;
  var text = parsedResultText[0].text;
  return {
    label: label,
    text: text
  };
}

function extractionEngineModelResultsToRegions(modelResults) {
  return modelResults.map(function (r) {
    var _labelAndTextFromResu = labelAndTextFromResultText(r.text),
        label = _labelAndTextFromResu.label,
        text = _labelAndTextFromResu.text;

    return {
      id: r.id,
      type: "box",
      visible: r.label === 'metadata' ? false : true,
      cls: label,
      highlighted: false,
      groupHighlighted: false,
      x: r.box.X1,
      y: r.box.Y1,
      w: r.box.X2 - r.box.X1,
      h: r.box.Y2 - r.box.Y1,
      groupId: r.groupId,
      text: text
    };
  });
}

function metadataEngineModelResultsToRegions(modelResults) {
  return modelResults.map(function (r) {
    return {
      id: r.id,
      type: "box",
      visible: false,
      cls: "metadata",
      highlighted: false,
      groupHighlighted: false,
      x: r.box.X1,
      y: r.box.Y1,
      w: r.box.X2 - r.box.X1,
      h: r.box.Y2 - r.box.Y1,
      groupId: r.groupId,
      text: r.text
    };
  });
}

function modelResultsToRegions(modelResults) {
  var _modelResults$find, _modelResults$find2;

  var extractionEngineRegions = extractionEngineModelResultsToRegions(((_modelResults$find = modelResults.find(function (mr) {
    return mr.name === 'extraction-engine';
  })) === null || _modelResults$find === void 0 ? void 0 : _modelResults$find.results) || []);
  var metadataEngineRegions = metadataEngineModelResultsToRegions(((_modelResults$find2 = modelResults.find(function (mr) {
    return mr.name === 'metadata-engine';
  })) === null || _modelResults$find2 === void 0 ? void 0 : _modelResults$find2.results) || []);
  return [].concat(_toConsumableArray(extractionEngineRegions), _toConsumableArray(metadataEngineRegions));
}

function photosToImages(photos) {
  return photos.map(function (photo) {
    return {
      id: photo.id,
      src: photo.fullsize.key,
      thumbnail: photo.thumbnail.key,
      name: photo.fullsize.key,
      regions: modelResultsToRegions(photo.modelResults.v1),
      metadata: photo.metadata,
      lockedUntil: photo.lockedUntil
    };
  });
}

export default photosToImages;